"use strict";

var _react = _interopRequireWildcard(require("react"));

var _reactTestingLibrary = require("react-testing-library");

var _checkVisibility = _interopRequireDefault(require("./checkVisibility"));

var _ = _interopRequireDefault(require("."));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

jest.mock('./checkVisibility');
var addEventListenerSpy = jest.spyOn(window, 'addEventListener');

var Foo = function Foo(_ref) {
  var partial = _ref.partial;
  var elRef = (0, _react.useRef)(null);
  var isVisible = (0, _.default)(elRef.current, {
    partial: partial
  });
  return _react.default.createElement("div", {
    ref: elRef
  }, isVisible ? 'visible' : 'not visible');
};

describe('useVisibility', function () {
  test('is initially not visible', function () {
    var _render = (0, _reactTestingLibrary.render)(_react.default.createElement(Foo, null)),
        container = _render.container;

    var el = container.firstChild;
    expect(el).toHaveTextContent('not visible');
    expect(_checkVisibility.default).not.toHaveBeenCalled();
  });
  test('attaches scroll and resize event listeners to window', function () {
    var _render2 = (0, _reactTestingLibrary.render)(_react.default.createElement(Foo, null)),
        rerender = _render2.rerender; // Force useEffect to run.


    rerender(_react.default.createElement(Foo, null));
    expect(addEventListenerSpy).toHaveBeenCalledWith('scroll', expect.any(Function));
    expect(addEventListenerSpy).toHaveBeenCalledWith('resize', expect.any(Function));
  });
  test('updates visibility after component is rendered', function () {
    var _render3 = (0, _reactTestingLibrary.render)(_react.default.createElement(Foo, null)),
        container = _render3.container,
        rerender = _render3.rerender;

    var el = container.firstChild;
    expect(el).toHaveTextContent('not visible');

    _checkVisibility.default.mockReturnValue(true); // Force useEffect to run.


    rerender(_react.default.createElement(Foo, null));
    expect(el).toHaveTextContent('visible');
    expect(_checkVisibility.default).toHaveBeenCalledWith(el, false);
  });
  test.skip('updates visibility on window scroll', function () {});
  test.skip('updates visibility on window resize', function () {});
  test('checks visibility using partial option', function () {
    var _render4 = (0, _reactTestingLibrary.render)(_react.default.createElement(Foo, {
      partial: true
    })),
        container = _render4.container,
        rerender = _render4.rerender;

    var el = container.firstChild; // Force useEffect to run.

    rerender(_react.default.createElement(Foo, {
      partial: true
    }));
    expect(_checkVisibility.default).toHaveBeenCalledWith(el, true);
  });
});